@@ -59,6 +59,21 @@ sub _get_drop_index_sql {
     . $self->{newline};
 }
 
+=head2 _get_drop_schema_sql
+
+Oracle do not support keyword 'if exists' in 'drop table' statement
+
+=cut
+
+sub _get_drop_schema_sql {
+  my ($self, $tablename) = @_;
+
+  return
+      qq{drop table $tablename}
+    . $self->{end_of_statement}
+    . $self->{newline};
+}
+
 
 
 1;
